getData4chr.lunge: get data on the presence of the chronic lung disease

View source: R/getData4chr.lunge.R

getData4chr.lungeR Documentation

get data on the presence of the chronic lung disease

Description

get data on the presence of the chronic lung disease

Usage

getData4chr.lunge(FRM_BAS)

Arguments

FRM_BAS

data.table containing the table FRM_BAS from the database of the PROGRESS study

Value

data.table. Each row corresponds to one patient and the columns contain information on the presence (1) or absence (0) of the chronic lung disease.

Examples

## Not run: 
excel_fn <- paste0("/net/ifs1/san_projekte/projekte/",
"PROGRESS/Datenmanagement/Data_freezes/",
"20190320/PROGRESS-freeze_201903_01.xlsx")
FRM_BAS <- readxl::read_excel(excel_fn, "FRM_BAS")
data.table::setDT(FRM_BAS)
getData4chr.lunge(FRM_BAS)

## End(Not run)

maciejrosolowski/progressdatenbankderivate documentation built on Nov. 29, 2024, 3:39 a.m.