View source: R/getData4chr.lunge.R
| getData4chr.lunge | R Documentation |
get data on the presence of the chronic lung disease
getData4chr.lunge(FRM_BAS)
FRM_BAS |
data.table containing the table FRM_BAS from the database of the PROGRESS study |
data.table. Each row corresponds to one patient and the columns contain information on the presence (1) or absence (0) of the chronic lung disease.
## Not run:
excel_fn <- paste0("/net/ifs1/san_projekte/projekte/",
"PROGRESS/Datenmanagement/Data_freezes/",
"20190320/PROGRESS-freeze_201903_01.xlsx")
FRM_BAS <- readxl::read_excel(excel_fn, "FRM_BAS")
data.table::setDT(FRM_BAS)
getData4chr.lunge(FRM_BAS)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.